Onion Tau Studio

?
🗣
Depth
Grayscale
Onion Tau Studio Help

#### Pan, Zoom, Rotate

🌐 3D Rotate - Click and drag
↔️ 2D Pan - Right-click and drag
🔍 Zoom - Scroll up and down

#### UI Controls

Play | Pause - Stop/resume the real-time depth data stream from the Tau Camera. When stopped, the point cloud will show the last frame.

Reset Point Camera - Reset the point cloud orientation and zoom

Auto Rotate Scene - Enable/disable automatic rotation of the point cloud

Increase or decrease the size of each pixel in the point cloud

Color Range Slider - Adjust the depth-based coloring of the point cloud

3D Integration Time Slider - Adjust the duration of time the sensor collects light data, similar to exposure time on a regular camera. Higher integration time will result in more detailed data.

#### How to Update Tau Studio

Open a command-line window and run this command:
`python -m pip install TauLidarServer --upgrade`

#### More Resources

Tau Product Page: https://TauLidar.com
Onion Community Forum: https://community.onion.io/
Tau Camera Get Started Guide
Tau Studio Get Started Guide
Tau Camera FAQs
GitHub Repos: tau-lidar-server, tau-lidar-camera

Feedback

#### We would love to hear from you! ❤️

Want to tell us what you think of the Tau Camera?
Let us know on Twitter - @OnionIoT

Want to connect with other Tau Camera users?
Check out the Onion Community Forum

Have a feature request or a bug that you’d like to report?
Post on GitHub and we'll take a look